function example 

    % moments of a real measurement trace (BC-pAug)
    moms=[ 0.00314282173600001
           4.17179800211485e-05
           2.01042352180101e-06
           1.81715481706899e-07
           2.52881412956407e-08
           4.94968256561858e-09
           1.21575695866302e-09
           3.40046113388869e-10
           1.02131958645415e-10
           3.19393258711259e-11];

    disp ('=== matching 3 moments, approximating the rest ===');
    
    % first match the first 3 moments, up to R=10 (R is related to the size
    % of the resulting PHs)
    phs = mommatch (moms(1:3), 2:10);   

    % This returns 34 PH distributions, all have the same first 3 moments
    % as the target. Now we selct the one whose higher moments are the 
    % closest to 'moms' (containing 10 moments!)
    %
    % NOTE: While selectbestph is purely based on moment here, it is
    % possible to select the best PH based on other distance measures. If
    % the pdf or cdf is avaialble, we can select the best based on relative
    % entropy, squared pdf/cdf difference, likelihood, etc.
    [bestPH, dist] = selectbestph (phs, moms);
    dist
    
    % display representation
    alpha = bestPH.alpha;
    A = bestPH.A;
    
    % display the target moments and the moments of bestPH
    [moms, phmoments(alpha,A,length(moms))]

    disp ('=== matching 5 moments, approximating the rest ===');
    
    % first match the first 5 moments
    phs = mommatch (moms(1:5), 3:10);   

    % This returns 121 PH distributions
    [bestPH, dist] = selectbestph (phs, moms);
    dist
    
    % display representation
    alpha = bestPH.alpha;
    A = bestPH.A;
    
    % display the target moments and the moments of bestPH. Very accurate
    % match!!!
    [moms, phmoments(alpha,A,length(moms))]

    disp ('=== matching 7 moments, approximating the rest ===');
    
    % first match the first 7 moments
    phs = mommatch (moms(1:7), 4:10);   

    % This returns 77 PH distributions
    [bestPH, dist] = selectbestph (phs, moms);
    dist
    
    % display representation
    alpha = bestPH.alpha;
    A = bestPH.A;
    
    % display the target moments and the moments of bestPH. Very accurate
    % match!!!
    [moms, phmoments(alpha,A,length(moms))]

end

