% Do moment matching given the order of the eigenvalues
%
% Input:
% ------
% rmoms: reduced moments (moments divided by the factorial), starting with
%        the 0th moment (=1). The number of moments must be even.
% orders: the multiplicities of the eigenvalues
%
% Output:
% -------
% ph: array of struct, with the solution ph
function ph = matchwithorders (rmoms, orders)

ph = [];
numOfSolutions = 0;
% solve polynomial system of equations
msol = solvepolysys (rmoms, orders);
for k=1:size(msol,1)
    
    % first, construst a matrix-exponential distribution 
    sol = msol(k,:);
    N = length(sol)/2;
    [eigs,ix] = sort(sol(N+1:end));
    ordersk = orders(ix);
    A = zeros(sum(ordersk));
    alpha = zeros(1,sum(ordersk));
    p = 1;
    for i=1:N
        for j=1:ordersk(i)
            A(p+j-1,p+j-1) = -eigs(i);
            if j<ordersk(i)
                A(p+j-1,p+j) = eigs(i);
            end
        end
        alpha(p) = sol(ix(i));
        p = p + ordersk(i);
    end
    
    % next, try to convert it to a monocyclic representation
    try
        [beta, B] = MonocyclicPHFromME (alpha, A, sum(orders)*10, 1e-14);   
        if ~isempty(beta) && min(beta)>0
            numOfSolutions = numOfSolutions+1;
            ph(numOfSolutions).alpha = beta;
            ph(numOfSolutions).A = B;
            ph(numOfSolutions).orders = orders;
%            fprintf ('Solution found! size=%d\n', length(beta));
%            orders
        end
    end
end
